@@ -11,6 +11,8 @@
 #include <gio/gio.h>
 #include <glib.h>
 
+#include <QMap>
+#include <QStringList>
 #include <QThread>
 #include <Transaction/Transaction.h>
 
@@ -40,6 +42,10 @@ public:
     }
 
     void addErrorMessage(const QString &error);
+    QMap<QString, QStringList> addedRepositories() const
+    {
+        return m_addedRepositories;
+    }
 
 Q_SIGNALS:
     void progressChanged(int progress);
@@ -47,8 +53,10 @@ Q_SIGNALS:
     void passiveMessage(const QString &msg);
 
 private:
-    FlatpakTransaction *m_transaction;
+    static gboolean
+    add_new_remote_cb(FlatpakTransaction * /*object*/, gint /*reason*/, gchar *from_id, gchar *suggested_remote_name, gchar *url, gpointer user_data);
 
+    FlatpakTransaction *m_transaction;
     bool m_result = false;
     bool m_cancelled = false;
     int m_progress = 0;
@@ -57,6 +65,7 @@ private:
     GCancellable *m_cancellable;
     FlatpakResource *const m_app;
     const Transaction::Role m_role;
+    QMap<QString, QStringList> m_addedRepositories;
 };
 
 #endif // FLATPAKTRANSACTIONJOB_H
